@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-:copyright: Copyright 2016-2022 Sphinx Confluence Builder Contributors (AUTHORS)
+:copyright: Copyright 2016-2023 Sphinx Confluence Builder Contributors (AUTHORS)
 :license: BSD-2-Clause (LICENSE)
 """
 
@@ -9,6 +9,8 @@ from sphinx.util import docutils
 from sphinxcontrib.confluencebuilder.builder import ConfluenceBuilder
 from sphinxcontrib.confluencebuilder.config import handle_config_inited
 from sphinxcontrib.confluencebuilder.config.manager import ConfigManager
+from sphinxcontrib.confluencebuilder.directives import ConfluenceExcerptDirective
+from sphinxcontrib.confluencebuilder.directives import ConfluenceExcerptIncludeDirective
 from sphinxcontrib.confluencebuilder.directives import ConfluenceExpandDirective
 from sphinxcontrib.confluencebuilder.directives import ConfluenceLatexDirective
 from sphinxcontrib.confluencebuilder.directives import ConfluenceMetadataDirective
@@ -41,7 +43,7 @@ try:
 except ImportError:
     imgmath = None
 
-__version__ = '1.9.0'
+__version__ = '2.0.0'
 
 
 def setup(app):
@@ -81,6 +83,8 @@ def setup(app):
     cm.add_conf('confluence_default_alignment', 'env')
     # Enablement of a generated domain index documents
     cm.add_conf('confluence_domain_indices')
+    # Confluence editor to target for publication.
+    cm.add_conf('confluence_editor', 'env')
     # File to get page header information from.
     cm.add_conf('confluence_header_file', 'env')
     # Dictionary to pass to header when rendering template
@@ -91,8 +95,6 @@ def setup(app):
     cm.add_conf('confluence_footer_data', 'env')
     # Enablement of a generated search documents
     cm.add_conf_bool('confluence_include_search')
-    # Enablement of the maximum document depth (before inlining).
-    cm.add_conf_int('confluence_max_doc_depth', 'env')
     # Enablement of a "page generated" notice.
     cm.add_conf_bool('confluence_page_generation_notice', 'env')
     # Enablement of publishing pages into a hierarchy from a root toctree.
@@ -163,6 +165,8 @@ def setup(app):
     cm.add_conf('confluence_client_cert_pass')
     # Disable SSL validation with Confluence server.
     cm.add_conf_bool('confluence_disable_ssl_validation')
+    # Whether to utilize the full width of a Confluence page (v2 only).
+    cm.add_conf_bool('confluence_full_width')
     # Ignore adding a titlefix on the index document.
     cm.add_conf_bool('confluence_ignore_titlefix_on_index', 'env')
     # Parent page's identifier to publish documents under.
@@ -225,6 +229,8 @@ def setup(app):
     cm.add_conf('confluence_adv_ignore_nodes')
     # Unknown node handler dictionary for advanced integrations.
     cm.add_conf('confluence_adv_node_handler')
+    # Permit any string value to be provided as the editor.
+    cm.add_conf('confluence_adv_permit_editor', 'env')
     # Enablement of permitting raw html blocks to be used in storage format.
     cm.add_conf_bool('confluence_adv_permit_raw_html', 'env')
     # List of optional features/macros/etc. restricted for use.
@@ -245,6 +251,8 @@ def setup(app):
     cm.add_conf_bool('confluence_purge_from_root')
     # replaced by confluence_space_key
     cm.add_conf('confluence_space_name')
+    # dropped
+    cm.add_conf_int('confluence_max_doc_depth')
 
     # ##########################################################################
 
@@ -283,6 +291,9 @@ def confluence_builder_inited(app):
         app.add_node(jira_issue)
 
     # register directives
+    app.add_directive('confluence_excerpt', ConfluenceExcerptDirective)
+    app.add_directive('confluence_excerpt_include',
+        ConfluenceExcerptIncludeDirective)
     app.add_directive('confluence_expand', ConfluenceExpandDirective)
     app.add_directive('confluence_latex', ConfluenceLatexDirective)
     app.add_directive('confluence_metadata', ConfluenceMetadataDirective)
@@ -330,9 +341,7 @@ def confluence_builder_inited(app):
     #
     # If 'sphinx.ext.imgmath' is not already explicitly loaded, bind it into the
     # setup process to a configurer can use the same configuration options
-    # outlined in the sphinx.ext.imgmath in this extension. This applies for
-    # Sphinx 1.8 and higher which math support is embedded; for older versions,
-    # users will need to explicitly load 'sphinx.ext.mathbase'.
+    # outlined in the sphinx.ext.imgmath in this extension.
     if imgmath is not None:
         if 'sphinx.ext.imgmath' not in app.config.extensions:
             imgmath.setup(app)
