@@ -1,13 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-:copyright: Copyright 2016-2022 Sphinx Confluence Builder Contributors (AUTHORS)
+:copyright: Copyright 2016-2023 Sphinx Confluence Builder Contributors (AUTHORS)
 :copyright: Copyright 2007-2021 by the Sphinx team (sphinx-doc/sphinx#AUTHORS)
 :license: BSD-2-Clause (LICENSE)
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import unicode_literals
 from collections import defaultdict
 from docutils import nodes
 from docutils.io import StringOutput
@@ -15,7 +12,6 @@ from os import path
 from sphinx import addnodes
 from sphinx import version_info as sphinx_version_info
 from sphinx.builders import Builder
-from sphinx.errors import ExtensionError
 from sphinx.locale import _ as SL
 from sphinx.util import status_iterator
 from sphinx.util.osutil import ensuredir
@@ -43,15 +39,11 @@ from sphinxcontrib.confluencebuilder.transmute import doctree_transmute
 from sphinxcontrib.confluencebuilder.util import ConfluenceUtil
 from sphinxcontrib.confluencebuilder.util import extract_strings_from_file
 from sphinxcontrib.confluencebuilder.util import first
+from sphinxcontrib.confluencebuilder.util import handle_cli_file_subset
 from sphinxcontrib.confluencebuilder.writer import ConfluenceWriter
 import io
 import os
 
-try:
-    basestring  # pylint: disable=E0601
-except NameError:
-    basestring = str
-
 
 class ConfluenceBuilder(Builder):
     allow_parallel = True
@@ -82,8 +74,8 @@ class ConfluenceBuilder(Builder):
         self.nav_next = {}
         self.nav_prev = {}
         self.omitted_docnames = []
-        self.publish_allowlist = []
-        self.publish_denylist = []
+        self.publish_allowlist = None
+        self.publish_denylist = None
         self.publish_docnames = []
         self.publisher = ConfluencePublisher()
         self.root_doc_page_id = None
@@ -185,19 +177,19 @@ class ConfluenceBuilder(Builder):
 
         def prepare_subset(option):
             value = getattr(config, option)
-            if not value:
+            if value is None:
                 return None
 
-            # if provided via command line, treat as a list
-            if option in config['overrides'] and isinstance(value, basestring):
-                value = value.split(',')
+            value = handle_cli_file_subset(config, option, value)
+            if value is None:
+                return None
 
-            if isinstance(value, basestring):
+            if isinstance(value, str):
                 files = extract_strings_from_file(value)
             else:
                 files = value
 
-            return set(files) if files else None
+            return set(files)
 
         self.publish_allowlist = prepare_subset('confluence_publish_allowlist')
         self.publish_denylist = prepare_subset('confluence_publish_denylist')
@@ -267,11 +259,9 @@ class ConfluenceBuilder(Builder):
         self._original_get_doctree = self.env.get_doctree
         self.env.get_doctree = self._get_doctree
 
-        # process the document structure of the root document, allowing:
-        #  - populating a publish order to ensure parent pages are created first
-        #     (when using hierarchy mode)
-        #  - squash pages which exceed maximum depth (if configured with a max
-        #     depth value)
+        # process the document structure of the root document, populating a
+        # publish order to ensure parent pages are created first (when using
+        # hierarchy mode)
         self.process_tree_structure(
             ordered_docnames, self.config.root_doc, traversed)
 
@@ -309,8 +299,12 @@ class ConfluenceBuilder(Builder):
                 self.state.register_toctree_depth(
                     docname, toctree.get('maxdepth'))
 
-            # register title targets for references
-            self._register_doctree_title_targets(docname, doctree)
+            # register title targets for references; however, not for v2
+            # editor since internal page links do not support linking
+            # directly to headers, so we will need to still generate anchors
+            # for these headers
+            if self.config.confluence_editor != 'v2':
+                self._register_doctree_title_targets(docname, doctree)
 
             # post-prepare a ready doctree
             self._prepare_doctree_writing(docname, doctree)
@@ -397,48 +391,17 @@ class ConfluenceBuilder(Builder):
         # for every doctree, pick the best image candidate
         self.post_process_images(doctree)
 
-    def process_tree_structure(self, ordered, docname, traversed, depth=0):
-        omit = False
-        max_depth = self.config.confluence_max_doc_depth
-        if max_depth is not None and depth > max_depth:
-            omit = True
-            self.omitted_docnames.append(docname)
+    def process_tree_structure(self, ordered, docname, traversed):
+        ordered.append(docname)
 
-        if not omit:
-            ordered.append(docname)
-
-        modified = False
         doctree = self.env.get_doctree(docname)
         for toctreenode in findall(doctree, addnodes.toctree):
-            if not omit and max_depth is not None:
-                if (toctreenode['maxdepth'] == -1 or
-                        depth + toctreenode['maxdepth'] > max_depth):
-                    new_depth = max_depth - depth
-                    assert new_depth >= 0
-                    toctreenode['maxdepth'] = new_depth
-            movednodes = []
             for child in toctreenode['includefiles']:
                 if child not in traversed:
                     self.state.register_parent_docname(child, docname)
                     traversed.append(child)
 
-                    children = self.process_tree_structure(
-                        ordered, child, traversed, depth + 1)
-                    if children:
-                        movednodes.append(children)
-                        self._fix_std_labels(child, docname)
-
-            if movednodes:
-                modified = True
-                toctreenode.replace_self(movednodes)
-                toctreenode.parent['classes'].remove('toctree-wrapper')
-
-        if omit:
-            container = addnodes.start_of_file(docname=docname)
-            container.children = doctree.children
-            return container
-        elif modified:
-            self.env.resolve_references(doctree, docname, self)
+                    self.process_tree_structure(ordered, child, traversed)
 
     def write_doc(self, docname, doctree):
         if docname in self.omitted_docnames:
@@ -793,7 +756,8 @@ class ConfluenceBuilder(Builder):
         if self.publish_denylist and docname in self.publish_denylist:
             return True
 
-        if self.publish_allowlist and docname not in self.publish_allowlist:
+        if self.publish_allowlist is not None and \
+                docname not in self.publish_allowlist:
             return True
 
         return False
@@ -837,69 +801,6 @@ class ConfluenceBuilder(Builder):
 
         return None
 
-    def _fix_std_labels(self, olddocname, newdocname):
-        """
-        fix standard domain labels for squashed documents
-
-        When Sphinx resolves references for a doctree ('resolve_references'),
-        the standard domain's internal labels are used to map references to
-        target documents. To support document squashing (aka. max depth pages),
-        this utility method helps override a document's tuple labels so that any
-        squashed page's labels can be moved into a parent document's label set.
-        """
-        # see also: sphinx/domains/std.py
-        std_domain = self.env.get_domain('std')
-        try:
-            citation_domain = self.env.get_domain('citation')
-        except ExtensionError:
-            citation_domain = None
-
-        if 'anonlabels' in std_domain.data:
-            anonlabels = std_domain.data['anonlabels']
-            for key, (fn, _l) in list(anonlabels.items()):
-                if fn == olddocname:
-                    data = anonlabels[key]
-                    anonlabels[key] = newdocname, data[1]
-
-        citations = None
-        if 'citations' in std_domain.data:  # Sphinx <2.1
-            citations = std_domain.data['citations']
-        elif citation_domain:  # Sphinx >=2.1
-            citations = citation_domain.citations
-        if citations:
-            for key, (fn, _l, _) in list(citations.items()):
-                if fn == olddocname:
-                    data = citations[key]
-                    citations[key] = newdocname, data[1], data[2]
-
-        if 'citation_refs' in std_domain.data:  # Sphinx <2.0
-            citation_refs = std_domain.data['citation_refs']
-            for key, _ in list(citation_refs.items()):
-                if fn == olddocname:
-                    data = citation_refs[key]
-                    citation_refs[key] = newdocname
-
-        if 'labels' in std_domain.data:
-            labels = std_domain.data['labels']
-            for key, (fn, _l, _l) in list(labels.items()):
-                if fn == olddocname:
-                    data = labels[key]
-                    labels[key] = newdocname, data[1], data[2]
-
-        if 'objects' in std_domain.data:
-            objects = std_domain.data['objects']
-            for key, (fn, _l) in list(objects.items()):
-                if fn == olddocname:
-                    data = objects[key]
-                    objects[key] = newdocname, data[1]
-
-        if 'progoptions' in std_domain.data:
-            progoptions = std_domain.data['progoptions']
-            for key, (fn, _l) in list(progoptions.items()):
-                if fn == olddocname:
-                    data = progoptions[key]
-                    progoptions[key] = newdocname, data[1]
-
     def _generate_special_document(self, docname, generator):
         """
         generate a special document
@@ -976,12 +877,12 @@ class ConfluenceBuilder(Builder):
         """
         override 'get_doctree' method
 
-        To support document squashing (aka. max depth pages), doctree's may be
-        loaded and manipulated before the writing stage. Normally, the writing
-        stage will load target doctree's from their source so there is no way to
-        pre-load and pass a document's doctree into the writing stage. To
-        overcome this, this extension hooks into the environment's 'get_doctree'
-        method and caches loaded document's doctree's into a map.
+        To support document editing, doctree's may be loaded and manipulated
+        before the writing stage. Normally, the writing stage will load target
+        doctree's from their source so there is no way to pre-load and pass a
+        document's doctree into the writing stage. To overcome this, this
+        extension hooks into the environment's 'get_doctree' method and
+        caches loaded document's doctree's into a map.
         """
         if docname not in self.cache_doctrees:
             self.cache_doctrees[docname] = self._original_get_doctree(docname)
@@ -1006,6 +907,13 @@ class ConfluenceBuilder(Builder):
 
         prev_next_loc = self.config.confluence_prev_next_buttons_location
 
+        # add page generation notice (first; if v2)
+        if self.config.confluence_editor == 'v2':
+            if self.config.confluence_page_generation_notice:
+                pgn_node = confluence_page_generation_notice()
+                header_node.append(pgn_node)
+                add_header_node = True
+
         # add source link
         if self.config.confluence_sourcelink:
             default_host = ''
@@ -1043,11 +951,12 @@ class ConfluenceBuilder(Builder):
             header_node.append(es_node)
             add_header_node = True
 
-        # add page generation notice
-        if self.config.confluence_page_generation_notice:
-            pgn_node = confluence_page_generation_notice()
-            header_node.append(pgn_node)
-            add_header_node = True
+        # add page generation notice (second; if not v2)
+        if self.config.confluence_editor != 'v2':
+            if self.config.confluence_page_generation_notice:
+                pgn_node = confluence_page_generation_notice()
+                header_node.append(pgn_node)
+                add_header_node = True
 
         # add header next/previous
         if prev_next_loc in ('top', 'both'):
