@@ -4,8 +4,8 @@
 :license: BSD-2-Clause (LICENSE)
 """
 
-from __future__ import print_function
 from collections import OrderedDict
+from docutils import __version__ as docutils_version
 from requests import __version__ as requests_version
 from sphinx import __version__ as sphinx_version
 from sphinx.application import Sphinx
@@ -19,16 +19,13 @@ from sphinxcontrib.confluencebuilder.publisher import ConfluencePublisher
 from sphinxcontrib.confluencebuilder.reportbuilder import ConfluenceReportBuilder
 from sphinxcontrib.confluencebuilder.util import ConfluenceUtil
 from sphinxcontrib.confluencebuilder.util import temp_dir
+from urllib.parse import urlparse
 from xml.etree import ElementTree
 import os
 import platform
 import sys
 import traceback
 
-try:
-    from urllib.parse import urlparse
-except ImportError:
-    from urlparse import urlparse
 
 #: rest point to fetch instance manifest state
 MANIFEST_PATH = 'rest/applinks/1.0/manifest'
@@ -277,6 +274,7 @@ def report_main(args_parser):
     print(' platform:', single_line_version(platform.platform()))
     print('   python:', single_line_version(sys.version))
     print('   sphinx:', single_line_version(sphinx_version))
+    print(' docutils:', single_line_version(docutils_version))
     print(' requests:', single_line_version(requests_version))
     print('  builder:', single_line_version(scb_version))
 
