@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-:copyright: Copyright 2020-2022 Sphinx Confluence Builder Contributors (AUTHORS)
+:copyright: Copyright 2020-2023 Sphinx Confluence Builder Contributors (AUTHORS)
 :license: BSD-2-Clause (LICENSE)
 """
 
@@ -8,14 +8,11 @@ from sphinxcontrib.confluencebuilder.config.notifications import deprecated
 from sphinxcontrib.confluencebuilder.config.notifications import warnings
 from sphinxcontrib.confluencebuilder.config.validation import ConfigurationValidation
 from sphinxcontrib.confluencebuilder.exceptions import ConfluenceConfigurationError
+from sphinxcontrib.confluencebuilder.std.confluence import EDITORS
+from sphinxcontrib.confluencebuilder.util import handle_cli_file_subset
 from requests.auth import AuthBase
 import os
 
-try:
-    basestring  # pylint: disable=E0601
-except NameError:
-    basestring = str
-
 
 def validate_configuration(builder):
     """
@@ -62,6 +59,12 @@ def validate_configuration(builder):
 
     # ##################################################################
 
+    # confluence_adv_permit_editor
+    validator.conf('confluence_adv_permit_editor') \
+             .bool()
+
+    # ##################################################################
+
     # confluence_adv_permit_raw_html
     validator.conf('confluence_adv_permit_raw_html') \
              .bool()
@@ -220,6 +223,23 @@ set to a list of domains (strings) to be included.
 
     # ##################################################################
 
+    # confluence_editor
+    validator.conf('confluence_editor') \
+             .string()
+
+    if config.confluence_editor:
+        if not config.confluence_adv_permit_editor:
+            if config.confluence_editor not in EDITORS:
+                raise ConfluenceConfigurationError('''\
+invalid editor provided in confluence_editor
+
+The following editors are supported:
+
+ - {}
+'''.format('\n - '.join(EDITORS)))
+
+    # ##################################################################
+
     # confluence_file_suffix
     validator.conf('confluence_file_suffix') \
              .string()
@@ -248,6 +268,12 @@ to a proper file path.
 
     # ##################################################################
 
+    # confluence_full_width
+    validator.conf('confluence_full_width') \
+             .bool()
+
+    # ##################################################################
+
     # confluence_global_labels
     try:
         validator.conf('confluence_global_labels') \
@@ -300,7 +326,7 @@ to a proper file path.
             issue = True
         else:
             for name, info in jira_servers.items():
-                if not isinstance(name, basestring):
+                if not isinstance(name, str):
                     issue = True
                     break
 
@@ -311,8 +337,8 @@ to a proper file path.
                 jira_id = info.get('id')
                 jira_name = info.get('name')
 
-                if not (isinstance(jira_id, basestring) and
-                        isinstance(jira_name, basestring)):
+                if not (isinstance(jira_id, str) and
+                        isinstance(jira_name, str)):
                     issue = True
                     break
 
@@ -392,23 +418,6 @@ The following keys are required:
 
     # ##################################################################
 
-    # confluence_max_doc_depth
-    try:
-        validator.conf('confluence_max_doc_depth') \
-                 .int_()
-    except ConfluenceConfigurationError as e:
-        raise ConfluenceConfigurationError('''\
-{msg}
-
-When limiting the document depth permitted for a building/publishing event, the
-defined maximum document depth must be defined as a non-negative integer value.
-
-If planning to use a depth of zero, it is recommended to use the
-'singleconfluence' builder instead.
-'''.format(msg=e))
-
-    # ##################################################################
-
     # confluence_navdocs_transform
     validator.conf('confluence_navdocs_transform') \
              .callable_()
@@ -476,18 +485,16 @@ navigational buttons onto generated pages. Accepted values include 'bottom',
         if not value:
             continue
 
-        # if provided via command line, treat as a list
+        # if provided a file via command line, treat as a list
         def conf_translate(value):
-            if option in config['overrides'] and isinstance(value, basestring):
-                value = value.split(',')
-            return value
+            return handle_cli_file_subset(config, option, value)
         value = conf_translate(value)
 
         try:
             validator.conf(option, conf_translate) \
                      .string_or_strings()
 
-            if isinstance(value, basestring):
+            if isinstance(value, str):
                 validator.docnames_from_file()
             else:
                 validator.docnames()
