@@ -7,6 +7,17 @@
 from sphinxcontrib.confluencebuilder.util import str2bool
 
 
+# configures the default editor to publication
+#
+# The following configures the default editor to use for publication. The
+# default value is "v1" (over the newer "v2"; Confluence default editor). This
+# is a result of not all Sphinx capabilities are supported with the newer
+# editor. Users can override the editor using configuration options -- but
+# this selection is solely driven on maximizing capabilities provided by
+# Sphinx over capabilities of Confluence.
+DEFAULT_EDITOR = 'v1'
+
+
 def apply_defaults(builder):
     """
     applies default values for select configurations
@@ -36,6 +47,9 @@ def apply_defaults(builder):
         if not isinstance(conf.confluence_client_cert, tuple):
             conf.confluence_client_cert = (conf.confluence_client_cert, None)
 
+    if conf.confluence_editor is None:
+        conf.confluence_editor = DEFAULT_EDITOR
+
     if conf.confluence_file_suffix:
         if conf.confluence_file_suffix.endswith('.'):
             conf.confluence_file_suffix = '.conf'
@@ -53,6 +67,9 @@ def apply_defaults(builder):
     if conf.confluence_mentions is None:
         conf.confluence_mentions = {}
 
+    if conf.confluence_page_hierarchy is None:
+        conf.confluence_page_hierarchy = True
+
     if conf.confluence_publish_intersphinx is None:
         conf.confluence_publish_intersphinx = True
 
@@ -84,8 +101,3 @@ def apply_defaults(builder):
             conf.confluence_parent_page = int(conf.confluence_parent_page)
         except ValueError:
             pass
-
-    # if running an older version of Sphinx which does not define `root_doc`,
-    # copy it over now from the legacy configuration
-    if 'root_doc' not in conf:
-        conf.root_doc = conf.master_doc
