@@ -5,6 +5,7 @@
 """
 
 from sphinxcontrib.confluencebuilder.logger import ConfluenceLogger as logger
+from sphinxcontrib.confluencebuilder.std.confluence import EDITORS
 import mimetypes
 
 # dictionary of deprecated configuration entries and associated message
@@ -15,6 +16,8 @@ DEPRECATED_CONFIGS = {
         'to be removed in a future version',
     'confluence_master_homepage':
         'use "confluence_root_homepage" instead',
+    'confluence_max_doc_depth':
+        'option does nothing',
     'confluence_parent_page_id_check':
         '"confluence_parent_page" now accepts a page id',
     'confluence_publish_subset':
@@ -47,14 +50,6 @@ def deprecated(validator):
         if config[key] is not None:
             logger.warn('%s deprecated; %s' % (key, msg))
 
-    # promote singleconfluence over confluence_max_doc_depth=0
-    if config.confluence_max_doc_depth == 0:
-        logger.warn('confluence_max_doc_depth with a value of zero '
-            "is deprecated; use the 'singleconfluence' builder instead")
-    elif config.confluence_max_doc_depth:
-        logger.warn('confluence_max_doc_depth is deprecated and will '
-            "be removed; consider using the 'singleconfluence' builder instead")
-
 
 def warnings(validator):
     """
@@ -88,3 +83,7 @@ def warnings(validator):
         logger.warn(
             'confluence_file_suffix ends with a period; '
             'a default value will be applied instead')
+
+    # confluence_editor assigned to an editor that is not supported
+    if config.confluence_editor and config.confluence_editor not in EDITORS:
+        logger.warn('confluence_editor configured with an unsupported editor')
