@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-:copyright: Copyright 2017-2022 Sphinx Confluence Builder Contributors (AUTHORS)
+:copyright: Copyright 2017-2023 Sphinx Confluence Builder Contributors (AUTHORS)
 :license: BSD-2-Clause (LICENSE)
 
 See also:
@@ -28,6 +28,7 @@ import time
 class ConfluencePublisher:
     def __init__(self):
         self.cloud = None
+        self.editor = None
         self.space_display_name = None
         self.space_type = None
         self._ancestors_cache = set()
@@ -39,6 +40,7 @@ class ConfluencePublisher:
         self.append_labels = config.confluence_append_labels
         self.debug = config.confluence_publish_debug
         self.dryrun = config.confluence_publish_dryrun
+        self.editor = config.confluence_editor
         self.notify = not config.confluence_disable_notifications
         self.onlynew = config.confluence_publish_onlynew
         self.parent_id = config.confluence_parent_page_id_check
@@ -239,7 +241,7 @@ reported a success (which can be permitted for anonymous users).
         return ancestors
 
     def get_base_page_id(self):
-        base_page_id = None
+        base_page_id = self.config.confluence_publish_root
 
         if not self.parent_ref:
             return base_page_id
@@ -421,7 +423,7 @@ reported a success (which can be permitted for anonymous users).
 
         return attachment_info
 
-    def get_page(self, page_name, expand='version'):
+    def get_page(self, page_name, expand='version', status='current'):
         """
         get page information with the provided page name
 
@@ -433,6 +435,7 @@ reported a success (which can be permitted for anonymous users).
         Args:
             page_name: the page name
             expand (optional): data to expand on
+            status (optional): the page status to search for
 
         Returns:
             the page id and page object
@@ -444,7 +447,7 @@ reported a success (which can be permitted for anonymous users).
             'type': 'page',
             'spaceKey': self.space_key,
             'title': page_name,
-            'status': 'current',
+            'status': status,
             'expand': expand,
         })
 
@@ -666,6 +669,16 @@ reported a success (which can be permitted for anonymous users).
 
         _, page = self.get_page(page_name, expand=expand)
 
+        # if the page is not found, but it determined to be an archived page,
+        # Confluence Cloud does not appear to support moving/updating an
+        # archived page back into a `current` mode -- instead, try to delete
+        # the archived page before generating a new page
+        if not page:
+            _, page = self.get_page(page_name, expand=expand, status='archived')
+            if page:
+                self.remove_page(page['id'])
+                page = None
+
         if self.onlynew and page:
             self._onlynew('skipping existing page', page['id'])
             return page['id']
@@ -913,21 +926,33 @@ reported a success (which can be permitted for anonymous users).
                     'value': data['content'],
                 }
             },
-            # only the legacy editor is supported at this time; forced v1
-            # since Confluence Cloud appears to have an inconsistent default
-            # editor
             'metadata': {
-                'properties': {
-                    'editor': {
-                        'value': 'v1',
-                    }
-                }
+                'properties': {},
             },
             'space': {
                 'key': self.space_key,
             },
         }
 
+        if self.editor:
+            page['metadata']['properties'] = {
+                'editor': {
+                    'value': self.editor,
+                },
+            }
+
+        if self.config.confluence_full_width is not None:
+            if self.config.confluence_full_width:
+                content_appearance = 'full-width'
+            else:
+                content_appearance = 'default'
+
+            page['metadata']['properties'] = {
+                'content-appearance-published': {
+                    'value': content_appearance,
+                },
+            }
+
         return page
 
     def _update_page(self, page, page_name, data, parent_id=None):
