@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-:copyright: Copyright 2018-2021 Sphinx Confluence Builder Contributors (AUTHORS)
+:copyright: Copyright 2018-2023 Sphinx Confluence Builder Contributors (AUTHORS)
 :license: BSD-2-Clause (LICENSE)
 """
 
 from contextlib import contextmanager
-from sphinxcontrib.confluencebuilder import compat
 from sphinxcontrib.confluencebuilder.std.confluence import API_REST_BIND_PATH
 from sphinxcontrib.confluencebuilder.std.confluence import FONT_SIZE
 from sphinxcontrib.confluencebuilder.std.confluence import FONT_X_HEIGHT
@@ -282,8 +281,7 @@ def getpass2(prompt='Password: '):
             'CONFLUENCEBUILDER_NO_GETPASS_HOOK' not in os.environ):
         subprocess.check_call(['stty', '-echo'])
         try:
-            input_ = compat.compat_input
-            value = input_(prompt)
+            value = input(prompt)
         finally:
             subprocess.check_call(['stty', 'echo'])
         print('')
@@ -292,6 +290,36 @@ def getpass2(prompt='Password: '):
         return getpass.getpass(prompt=prompt)
 
 
+def handle_cli_file_subset(config, option, value):
+    """
+    process a file subset entry based on a cli-provided value
+
+    If the value of an option is provided in the "overrides", this is (most
+    likely) an option set from the command line. If this string points to an
+    existing file, we will return the provided file name as is. However, if
+    this is a string, it is most likely a list of files from the command line.
+
+    Args:
+        config: the sphinx configuration
+        option: the key associated to this configuration value
+        value: the configuration value
+
+    Returns:
+        the resolved configuration value
+    """
+
+    if option in config['overrides'] and isinstance(value, str):
+        if not value:
+            # an empty command line subset is an "unset" request
+            # (and not an empty list); if no values are detected,
+            # return `None`
+            return None
+        elif not os.path.isfile(value):
+            value = value.split(',')
+
+    return value
+
+
 def remove_nonspace_control_chars(text):
     """
     remove any non-space control characters from text
@@ -307,7 +335,7 @@ def remove_nonspace_control_chars(text):
     """
 
     return ''.join(c for c in text if c.isspace()
-        or unicodedata.category(c)[0] != 'C')
+        or unicodedata.category(c) != 'Cc')
 
 
 def str2bool(value):
